<?php
/**
 * authority functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package authority
 */
ob_start();
if ( ! function_exists( 'authoritymarketer_setup' ) ) :
	/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
	function authoritymarketer_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on authority, use a find and replace
		 * to change 'authoritymarketer' to the name of your theme in all the template files.
		 */

		/* inclide localization file */
		load_theme_textdomain( 'authoritymarketer', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary', 'authoritymarketer' ),
		) );

			/*
             * Switch default core markup for search form, comment form, and comments
             * to output valid HTML5.
			 */
			add_theme_support( 'html5', array(
				'search-form',
				'comment-form',
				'comment-list',
				'gallery',
				'caption',
			) );

			/*
             * Enable support for Post Formats.
             * See https://developer.wordpress.org/themes/functionality/post-formats/
			 */
			add_theme_support( 'post-formats', array(
				'aside',
				'image',
				'video',
				'audio',
				'quote',
				'link',
			) );

			// Set up the WordPress core custom background feature.
			add_theme_support( 'custom-background', apply_filters( 'authority_custom_background_args', array(
				'default-color' => 'ffffff',
				'default-image' => '',
			) ) );

			add_theme_support( 'custom-header', apply_filters( 'authoritymarketer_custom_header_args', array(
				'width'                  => 1900,
				'height'                 => 280,
				'flex-height'            => true,
			) ) );

			$GLOBALS['content_width'] = apply_filters( 'authoritymarketer_content_width', 640 );

	}
endif;
add_action( 'after_setup_theme', 'authoritymarketer_setup' );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function authoritymarketer_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'authoritymarketer' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Header Right', 'authoritymarketer' ),
		'id'            => 'header_right',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => esc_html__( 'Header Bottom', 'authoritymarketer' ),
		'id'            => 'header_bottom',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer Top', 'authoritymarketer' ),
		'id'            => 'footer_top',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Footer', 'authoritymarketer' ),
		'id'            => 'footer_content',
		'description'   => '',
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

}
add_action( 'widgets_init', 'authoritymarketer_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function authoritymarketer_scripts() {

	wp_enqueue_style( 'authoritymarketer-style', get_stylesheet_uri() );

	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css' );

	//import fonts
	wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Lato:400,300,700|Roboto' );

	// modernizr (without media query polyfill)
	wp_enqueue_script( 'authoritymarketer-menu', get_stylesheet_directory_uri() . '/js/menu.js', array(), '', true );

		wp_enqueue_style( 'authoritymarketer-menu', get_template_directory_uri() . '/css/menu.css' );
	wp_enqueue_style( 'authoritymarketer-animate', get_template_directory_uri() . '/css/animate.css' );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_enqueue_script( 'jquery', false, array(), false, false );

	$script = 'var dropdown = document.getElementById("cat");
				function onCatChange() {
					if ( dropdown.options[dropdown.selectedIndex].value > 0 ) {
					   location.href = "' . esc_url( home_url( '/' ) ) . '?cat="+dropdown.options[dropdown.selectedIndex].value;
					}
				}
				dropdown.onchange = onCatChange;';

	wp_add_inline_script( 'authoritymarketer-script',$script );
}
add_action( 'wp_enqueue_scripts', 'authoritymarketer_scripts' );

/*editor style css*/
function authoritymarketer_editor_styles() {
	add_editor_style( 'editor-style.css' );
}
add_action( 'admin_init', 'authoritymarketer_editor_styles' );

add_action( 'wp_enqueue_scripts', 'authoritymarketer_common_scripts' );
add_action( 'admin_enqueue_scripts', 'authoritymarketer_common_scripts' );


function authoritymarketer_common_scripts() {

	wp_enqueue_script( 'authoritymarketer-script', get_stylesheet_directory_uri() . '/js/authoritymarketer-script.js', array(), '', true );

	$authoritymarketer_settings = get_option( authoritymarketer_prefix() . '_theme_settings' );
	if ( isset( $authoritymarketer_settings['authoritymarketer_google_fonts'] ) ) {


		$authoritymarketer_google_fonts = $authoritymarketer_settings['authoritymarketer_google_fonts'];

		if ( isset( $authoritymarketer_google_fonts ) && $authoritymarketer_google_fonts != '' ) {
			if ( strstr( $authoritymarketer_google_fonts,'+' ) ) {
				$css_gogole_font = str_replace( '+',' ',$authoritymarketer_google_fonts );
			} else {
				$css_gogole_font = $authoritymarketer_google_fonts;
			}

			wp_enqueue_style( 'google-fonts', authoritymarketer_google_fonts_url( $authoritymarketer_google_fonts ), array(), '1.0.0' );

			$style = ' html body, body .accordion dd > a, body button, body .button, body .label, body .pricing-table .title, body .pricing-table .price, body .side-nav, body .side-nav li.active > a:first-child:not(.button), body .sub-nav dt, body .sub-nav dd, body .sub-nav li, body .tabs dd > a, body .top-bar-section ul li > a, body h1, body h2, body h3, body h4, body h5, body h6, body .commentlist .comment-reply-link{font-family: ' . $css_gogole_font . ', sans-serif;}';

			wp_add_inline_style( 'authoritymarketer-style',$style );

		}
	}

	if ( isset( $authoritymarketer_settings['authoritymarketer_fonts_size'] ) ) {

		$authoritymarketer_google_fonts = $authoritymarketer_settings['authoritymarketer_fonts_size'];

		if ( $authoritymarketer_google_fonts ) {
			$style = 'html, body{font-size: ' . $authoritymarketer_google_fonts . 'px !important;}';
			wp_add_inline_style( 'authoritymarketer-style',$style );
		}
	}

}

/* Add google fonts */
function authoritymarketer_google_fonts_url( $fonts ) {

	$font_url = '';

	$font_url = add_query_arg( 'family', urlencode( $fonts ), '//fonts.googleapis.com/css' );

	return $font_url;

}



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

function authoritymarketer_body_classes( $classes ) {
	// Adds a class of group-blog to blogs with more than 1 published author.
	if ( is_multi_author() ) {
		$classes[] = 'group-blog';
	}

	// Adds a class of hfeed to non-singular pages.
	if ( ! is_singular() ) {
		$classes[] = 'hfeed';
	}

	//adds a class of

	return $classes;
}
add_filter( 'body_class', 'authoritymarketer_body_classes' );


/*
 * This is a modified the_author_posts_link() which just returns the link.
 *
 * This is necessary to allow usage of the usual l10n process with printf().
 */
function authoritymarketer_author_link() {
	global $authordata;
	if ( ! is_object( $authordata ) ) {
		return false;
	}
	$link = sprintf(
		'<a href="%1$s" title="%2$s" rel="author">%3$s</a>',
		esc_url( get_author_posts_url( $authordata->ID, $authordata->user_nicename ) ),
		esc_attr( sprintf( __( 'Posts by %s','authoritymarketer' ), get_the_author() ) ), // No further l10n needed, core will take care of this one
		esc_html( get_the_author() )
	);
	return $link;
}


/*
get the image of the relevant size pass in argument if no size pass in argument it will return the thumbnail
*/
function authoritymarketer_image_withinfo( $iPostID, $img_size = 'thumb', $no_images = '' ) {

	$arrImages = get_children( 'order=ASC&orderby=menu_order ID&post_type=attachment&post_mime_type=image&post_parent=' . (isset($iPostID)) ? $iPostID : '' );
	$counter = 0;
	$return_arr = array();

	if ( has_post_thumbnail( $iPostID ) ) {

		$img_arr = wp_get_attachment_image_src( get_post_thumbnail_id( $iPostID ), $img_size );
		$imgarr['id'] = get_post_thumbnail_id( $iPostID );
		;
		$imgarr['file'] = $img_arr[0];
		$return_arr[] = $imgarr;

	} else {
		if ( $arrImages ) {

			foreach ( $arrImages as $key => $val ) {
				$id = $val->ID;
				if ( $val->post_title != '' ) {
					if ( $img_size == 'thumb' ) {
						$img_arr = wp_get_attachment_image_src( $id, 'thumbnail' ); // Get the thumbnail url for the attachment
						$imgarr['id'] = $id;
						$imgarr['file'] = $img_arr[0];
						$return_arr[] = $imgarr;
					} else {
						$img_arr = wp_get_attachment_image_src( $id, $img_size );
						$imgarr['id'] = $id;
						$imgarr['file'] = $img_arr[0];
						$return_arr[] = $imgarr;
					}
				}
				$counter++;
				if ( $no_images != '' && $counter == $no_images ) {
					break;
				}
			}
		} else {
				$imgarr['id'] = 0;
				$imgarr['file'] = '//placehold.it/185x130/333333/999999&text=Thumbnail';
				$return_arr[] = $imgarr;
		}
	}// End if().
	return $return_arr;
}

/*Comment */
function authoritymarketer_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	extract( $args, EXTR_SKIP );

	if ( 'div' == $args['style'] ) {
		$tag = 'div';
		$add_below = 'comment';
	} else {
		$tag = 'li';
		$add_below = 'div-comment';
	}
?>
	<<?php echo esc_attr( $tag ) ?> <?php comment_class( empty( $args['has_children'] ) ? '' : 'parent' ) ?> id="comment-<?php intval( comment_ID() ) ?>">
	<?php if ( 'div' != $args['style'] ) : ?>
	<div id="div-comment-<?php intval( comment_ID() ) ?>" class="comment-body">
	<?php endif; ?>
	<div class="comment-author vcard">
	<?php if ( $args['avatar_size'] != 0 ) { echo wp_kses( get_avatar( $comment, $args['avatar_size'] ) , wp_kses_allowed_html( 'post' ) );} ?>
	<?php printf( ( '<cite class="fn">%s</cite>' ), get_comment_author_link() ); ?>

	<div class="comment-meta commentmetadata">
		<a href="<?php echo htmlspecialchars( get_comment_link(
		$comment->comment_ID ) ) ?>"><?php printf( __( '%1$s at %2$s','authoritymarketer' ), get_comment_date(),  get_comment_time() ) ?>
		</a>
		<?php edit_comment_link( esc_html__( '(Edit)','authoritymarketer' ),'  ','' ) ?>
	</div>
	</div>
	<?php if ( $comment->comment_approved == '0' ) : ?>
		<em class="comment-awaiting-moderation"><?php esc_html_e( 'Your comment is awaiting moderation.','authoritymarketer' ); ?></em>
		<br />
	<?php endif; ?>

	<div class="comment-meta comment-footer edit-reply">
	<?php comment_reply_link( array_merge( $args, array(
		'add_below' => intval( $add_below ),
		'depth' => intval( $depth ),
		'max_depth' => intval( $args['max_depth'] ),
	) ) ); ?>
	</div>
	<div class="comment-content">
		<?php comment_text(); ?>
	</div>

	<?php if ( 'div' != $args['style'] ) : ?>
	</div>
	<?php endif; ?>

<?php
}

add_filter( 'wp_nav_menu_args', 'authoritymarketer_nav_menu_args' );
function authoritymarketer_nav_menu_args( $args = '' ) {
	$args['container'] = false;
	return $args;
}

if ( ! function_exists( 'authoritymarketer_reverse_strrchr' ) ) {
	function authoritymarketer_reverse_strrchr( $haystack, $needle, $trail ) {
		return strrpos( $haystack, $needle ) ? substr( $haystack, 0, strrpos( $haystack, $needle ) + $trail ) : false;
	}
}

if ( ! function_exists( 'authoritymarketer_excerpt' ) ) {
	function authoritymarketer_excerpt( $length ) {
		// Max excerpt length. Length is set in characters
		global $post;
		$length = ($length == '')? '50' : $length;
		/*condition for supreme related theme*/

		$text = $post->post_excerpt;
		if ( $text == '' ) {
			$text = $post->post_content;
			$text = apply_filters( 'the_excerpt', $text );
			$text = str_replace( ']]>', ']]>', $text );
		}
		$text = strip_shortcodes( $text ); // optional, recommended
		$text = strip_tags( $text ); // use ' $text = strip_tags($text,'<p><a>'); ' if you want to keep some tags

		$text = wp_trim_words( $text,$length ); /* shows perticular words */
		if ( authoritymarketer_reverse_strrchr( $text, '.', 1 ) ) {
			$excerpt = authoritymarketer_reverse_strrchr( $text, '.', 1 );
		} else {
			$excerpt = $text;
		}

		if ( $excerpt ) {
			echo apply_filters( 'the_excerpt',$excerpt );
		} else {
			echo apply_filters( 'the_excerpt',$text );
		}
	}
}

function authoritymarketer_post_first_image() {
	global $post;
	if ( has_post_thumbnail() ) {
		$thumb_id = get_post_thumbnail_id();
		$thumb_url_array = wp_get_attachment_image_src( $thumb_id, 'full', true );
		$first_img = $thumb_url_array[0];
	} else {
		$first_img = '';
		$output = preg_match_all( '/<img.+src=[\'"]([^\'"]+)[\'"].*>/i', $post->post_content, $matches );
		if ( ! empty( $matches [1] [0] ) ) {
			$first_img = (isset($matches[1][0])) ? $matches[1][0] : '' ;
			if ( empty( $first_img ) ) { //Defines a default image
				  $first_img = get_template_directory_uri() . '/images/templatic-home-page-banner.png';
			}
			if ( ! preg_match( '~^(?:f|ht)tps?://~i', $first_img ) ) {
				  $first_img = 'https:' . $first_img;
			}
		}
	}
	?>
  <span itemprop="image" itemscope itemtype="https://schema.org/ImageObject">
		<meta itemprop="url" content="<?php echo esc_url( $first_img ); ?>">
		<meta itemprop='width' content='500'/>
		<meta itemprop='height' content='500'/>
  </span>
	<?php
}

if ( ! function_exists( 'authoritymarketer_page_posted_on' ) ) :

	/**
	 * Prints HTML with meta information for the current post-date/time and author.
	 */
	function authoritymarketer_page_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf($time_string, esc_attr( get_the_date( 'c' ) ), esc_html( get_the_date() ), esc_attr( get_the_modified_date( 'c' ) ), esc_html( get_the_modified_date() )
		);

		$posted_on = sprintf(
			esc_html_x( 'Posted on %s', 'post date', 'authoritymarketer' ), '<a href="' . esc_url( get_permalink() ) . '" rel="bookmark"><span datetime="' . get_the_time( 'c' ) . '" itemprop="datePublished" content="' . get_the_time( 'c' ) . '">' . $time_string . '</span></a>'
		);

		$byline = sprintf(
			esc_html_x( 'by %s', 'post author', 'authoritymarketer' ), '<span class="author vcard" itemprop="author" itemscope itemtype="https://schema.org/Person">' . esc_html( get_the_author() ) . ' <span itemprop="name">Templatic</span></span>'
		);

		echo '<span class="posted-on hide_class">' . wp_kses( $posted_on , wp_kses_allowed_html( 'post' ) ) . '</span><span class="byline hide_class"> ' . wp_kses( $byline , wp_kses_allowed_html( 'post' ) ) . '</span>'; // WPCS: XSS OK.
	}

endif;

function authoritymarketer_publisher_structured_data() {
	?>
	<div class="publisher-img" itemprop="publisher" itemscope itemtype="https://schema.org/Organization">
	<div itemprop="logo" itemscope itemtype="https://schema.org/ImageObject">
	  <meta itemprop="url" content="<?php echo get_stylesheet_directory_uri() ?>/images/logo.png">
	  <meta itemprop="width" content="100">
	  <meta itemprop="height" content="100">
	</div>
	<meta itemprop="name" content="<?php echo esc_attr( get_bloginfo( 'name' ) ); ?>">
	</div>
	<meta itemprop="dateModified" content="<?php echo get_the_time( 'c' ); ?>"/>
	<?php
}

function authoritymarketer_display_related_post() {
	global $post;
	$categories = get_the_category();
	if ( $categories ) {
		foreach ( $categories as $category ) {
			$cat[] = $category->cat_ID;
		}
			$args = array(
			'cat' => $cat,
			'order' => 'DESC',
			'orderby' => 'rand',
			'post__not_in' => array( $post->ID ),
			'posts_per_page' => 3,
		);
		$related_query = null;
		$related_query = new WP_Query( $args );
		if ( $related_query->have_posts() ) {
			echo '<div class="related_posts">';
			echo '<h3>' . esc_html__( 'You may also like','authoritymarketer' ) . '</h3>';
			echo '<ul>';
			while ( $related_query->have_posts() ) : $related_query->the_post(); ?>
			<li>
				<div class="post_img"><a class="post-thumb" href="<?php echo esc_url( get_permalink() ) ?>" rel="bookmark">
				<?php
				if ( get_the_post_thumbnail_url( $post,'medium' ) ) {
					?><img src="<?php esc_url( the_post_thumbnail_url( 'medium' ) ); ?>" alt="<?php echo esc_attr( get_the_title() );?>" />
				<?php
				}
				?>
				</a></div>

				<div class="post_title">
				<a class="post-thumb" href="<?php echo esc_url( get_permalink() ) ?>" rel="bookmark"><?php the_title(); ?></a>
			<span class="category"><?php
				$related_categories = get_the_category();
				$last = count( $related_categories );
				$count = 0;
				$category_html = '';
			foreach ( $related_categories as $related_cat ) {
				$count++;
				if ( $count == $last ) {
					$category_html .= '<a href="' . esc_url( get_term_link( $related_cat->term_id ) ) . '">' . esc_attr( $related_cat->name ) . '</a>';
				} else {
					$category_html .= '<a href="' . esc_url( get_term_link( $related_cat->term_id ) ) . '">' . esc_attr( $related_cat->name ) . '</a> / ';
				}
			}
				echo wp_kses( $category_html , wp_kses_allowed_html( 'post' ) );
				?></span>
				</div>
			</li>
				<?php
				endwhile;
			wp_reset_query();
			wp_reset_postdata();
			echo '</div></ul>';
		}// End if().
	}// End if().
}

add_action( 'wp_head', 'authoritymarketer_customizer_style' );
/* add customiser css in front style.css */
if ( ! function_exists( 'authoritymarketer_customizer_style' ) ) {

	function authoritymarketer_customizer_style() {

		if ( file_exists( get_stylesheet_directory() . '/admin-style.php' ) ) {
			include_once( get_stylesheet_directory() . '/admin-style.php' ); // child theme css file
		} elseif ( file_exists( get_template_directory() . '/front-style.php' ) ) {
			include_once( get_template_directory() . '/front-style.php' );
		}
	}
}

include_once( get_template_directory() . '/admin.php' );

function authoritymarketer_prefix() {
	return 'authoritymarketer';
}


add_action( 'wp_head','authoritymarketer_global_settings' );

function authoritymarketer_global_settings() {
	global $authoritymarketer_settings;
	$authoritymarketer_settings = get_option( authoritymarketer_prefix() . '_theme_settings' );
	return $authoritymarketer_settings;
}

add_action( 'customize_register' , 'authoritymarketer_cutomizer_footer_options',100 );

function authoritymarketer_cutomizer_footer_options( $wp_customize ) {
	global $wp_customize;

	$wp_customize->remove_section( 'header_image' );

	$wp_customize->add_section( 'authoritymarketer_logo_section' , array(
			'title'       => esc_html__( 'Site Logo', 'authoritymarketer' ),
			'priority'    => 30,
			'description' => esc_html__( 'Upload a logo to replace the default site name and description in the header','authoritymarketer' ),
	) );

	$wp_customize->add_section(
		'authoritymarketer_footer_options',
		array(
			'title'       => esc_html__( 'Footer Settings', 'authoritymarketer' ),
			'priority'    => 100,
			'capability'  => 'edit_theme_options',
			'description' => esc_html__( 'Change footer options here.', 'authoritymarketer' ),
		)
	);

	//adding setting for footer text area
	$wp_customize->add_setting('footer_text', array(
		'default'        => esc_html__( 'Default Text For Footer Section', 'authoritymarketer' ),
		'sanitize_callback' => 'authoritymarketer_footer_options',
	));

	$wp_customize->add_control('footer_text', array(
		'label'   => esc_html__( 'Footer Text Here', 'authoritymarketer' ),
		'section' => 'authoritymarketer_footer_options',
		'type'    => 'textarea',
	));

	$wp_customize->add_section('homepage_settings_section', array(
		'title'       => esc_html__( 'Homepage banner after second post', 'authoritymarketer' ),
		'priority'    => 40,
	));
	//adding setting for footer text area
	$wp_customize->add_setting('homepage_first_banner', array(
		'default'        => '',
		'sanitize_callback' => 'authoritymarketer_footer_options',
	));
	$wp_customize->add_control('homepage_first_banner', array(
		'label'   	=> esc_html__( 'Homepage banner after second post', 'authoritymarketer' ),
		'section' 	=> 'homepage_settings_section',
		'type'    	=> 'textarea',
	));

	//adding setting for footer text area
	$wp_customize->add_setting('homepage_second_banner', array(
		'default'        => '',
		'sanitize_callback' => 'authoritymarketer_footer_options',
	));
	$wp_customize->add_control('homepage_second_banner', array(
		'label'   => esc_html( 'Homepage banner after fourth post','authoritymarketer' ),
		'section' => 'homepage_settings_section',
		'type'    => 'textarea',
	));

	/**
	 * Sanitizes the footer content on the customize screen.  Users with the 'unfiltered_html' cap can post
	 * anything.  For other users, wp_filter_post_kses() is ran over the setting.
	 * @param mixed $setting The current setting passed to sanitize.
	 * @param object $object The setting object passed via WP_Customize_Setting.
	 * @return mixed $setting
	 */
	function authoritymarketer_footer_options( $setting, $object ) {
		/* Get the theme prefix. */
		$prefix = 'authoritymarketer';
		/* Make sure we kill evil scripts from users without the 'unfiltered_html' cap. */
		if ( 'authoritymarketer_footer[footer_text]' == $object->id && ! current_user_can( 'unfiltered_html' ) ) {
			$setting = stripslashes( wp_filter_post_kses( addslashes( $setting ) ) );
		}
		/* Return the sanitized setting and apply filters. */
		return apply_filters( "{$prefix}_customize_sanitize", $setting, $object );
	}

}


/* Show all free themes at "Download More Themes!" section in backend */
add_action( 'authoritymarketer_free_themes','authoritymarketer_free_themes' );
if ( ! function_exists( 'authoritymarketer_free_themes' ) ) {
	function authoritymarketer_free_themes() {
		global $wp_version;

		//avoid undefined vars
		$data = '';
		$sourceNode = '';

		if ( false === ( $response = get_transient( '_tevolution_free_themes' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'sslverify' => false, /* when curl doesn't support ssl */
				'user-agent' => (isset($wp_version)) ? 'WordPress/' . $wp_version . '; ' . home_url() : 'WordPress/' . home_url(),
				'cookies' => array(),
				)
			);
			set_transient( '_tevolution_free_themes', $response, 12 * HOUR_IN_SECONDS );
		}


		/* get responase */
		if ( ! is_wp_error( $response ) ) {
			$data = $response['body'];
		}

		/* read data from xml file */
		if ( $data ) {
			$doc = new DOMDocument();
			if($doc) {
				$doc->loadXML( $data );
			}
			$sourceNode = $doc->getElementsByTagName( 'templatic-free-theme' );
		}

		if ( $sourceNode ) {

			echo '<div class="theme-list">';

			foreach ( $sourceNode as $source ) {

				/* get theme name */
				$theme_name = $source->getElementsByTagName( 'theme-name' );
				$name = $theme_name->item( 0 )->nodeValue;

				/* get theme image url */
				$theme_image = $source->getElementsByTagName( 'theme-image' );
				$image = $theme_image->item( 0 )->nodeValue;

				/* get theme description */
				$theme_description = $source->getElementsByTagName( 'theme-description' );
				$description = $theme_description->item( 0 )->nodeValue;

				/* get theme sale's page url */
				$theme_salespage_url = $source->getElementsByTagName( 'theme-salespage-url' );
				$theme_salespage = $theme_salespage_url->item( 0 )->nodeValue;

				echo '<div class="array-theme">';
				echo '<div class="theme-image">';
					echo '<a href="' . $theme_salespage . '" class="theme-link"><img alt="' . $name . '" src="' . $image . '"></a>';
				echo '</div>';
				echo '<h3><a href="' . $theme_salespage . '"> ' . $name . ' </a></h3>';
				echo '<p>' . $description . '</p>';
				echo '</div>';

			}

			echo '</div>';
		}// End if().

	}
}// End if().


/* Show all free plugin at "Download More Free Plugins!" section in backend */
add_action( 'authoritymarketer_free_plugins','authoritymarketer_free_plugins' );
if ( ! function_exists( 'authoritymarketer_free_plugins' ) ) {
	function authoritymarketer_free_plugins() {
		global $wp_version;
		//avoid undefined vars
		$data = '';
		$sourceNode = '';

		if ( false === ( $response = get_transient( '_authoritymarketer_free_plugins' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'sslverify' => false, /* when curl doesn't support ssl */
				'user-agent' => (isset($wp_version)) ? 'WordPress/' . $wp_version . '; ' . home_url() : 'WordPress/' . home_url(),
				'cookies' => array(),
				)
			);
			set_transient( '_authoritymarketer_free_plugins', $response, 12 * HOUR_IN_SECONDS );
		}

		/* get responase */
		if ( ! is_wp_error( $response ) ) {
			$data = $response['body'];
		}

		/* read data from xml file */
		if ( $data ) {
			$doc = new DOMDocument();
			if($doc) {
				$doc->loadXML( $data );
			}
			$sourceNode = $doc->getElementsByTagName( 'templatic-free-plugin' );
		}

		if ( $sourceNode ) {

			echo '<div class="theme-list">';

			foreach ( $sourceNode as $source ) {

				/* get plugin name */
				$plugin_name = $source->getElementsByTagName( 'plugin-name' );
				$name = $plugin_name->item( 0 )->nodeValue;

				/* get plugin image url */
				$plugin_image = $source->getElementsByTagName( 'plugin-image' );
				$image = $plugin_image->item( 0 )->nodeValue;

				/* get plugin description */
				$plugin_description = $source->getElementsByTagName( 'plugin-description' );
				$description = $plugin_description->item( 0 )->nodeValue;

				/* get plugin sale's page url */
				$plugin_salespage_url = $source->getElementsByTagName( 'plugin-salespage-url' );
				$plugin_salespage = $plugin_salespage_url->item( 0 )->nodeValue;

				echo '<div class="array-theme">';
				echo '<div class="theme-image">';
					echo '<a href="' . esc_url( $plugin_salespage ) . '" class="theme-link"><img alt="' . esc_attr( $name ) . '" src="' . esc_url( $image ) . '"></a>';
				echo '</div>';
				echo '<h3><a href="' . esc_url( $plugin_salespage ) . '"> ' . esc_attr( $name ) . ' </a></h3>';
				echo '<p>' . wp_kses( $description , wp_kses_allowed_html( 'post' ) ) . '</p>';
				echo '</div>';

			}

			echo '</div>';
		}// End if().

	}
}// End if().

add_action( 'authoritymarketer_help','authoritymarketer_help_tab' );
if ( ! function_exists( 'authoritymarketer_help_tab' ) ) {
	function authoritymarketer_help_tab() {

		if ( false === ( $response = get_transient( '_authoritymarketer_free_themes' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				)
			);
			set_transient( '_authoritymarketer_free_themes', $response, 12 * HOUR_IN_SECONDS );
		}

		if ( false === ( $response = get_transient( '_authoritymarketer_free_themes' ) ) ) {
			$response = wp_remote_get( '//templatic.net/api/templatic-free-themes.xml', array(
				'method' => 'POST',
				'timeout' => 45,
				'redirection' => 5,
				'httpversion' => '1.0',
				'blocking' => true,
				)
			);
			set_transient( '_authoritymarketer_free_themes', $response, 12 * HOUR_IN_SECONDS );
		}

		//define emrty vars to avoid undefind var error
		$data = '';
		$sourceNode = '';

		if ( is_wp_error( $response ) ) {
				echo '<div id="standalone_plugin_error" class="metabox-holder wrapper widgets-holder-wrap">';
				printf( __( '<strong>templatic.com connect Error</strong>: %s','authoritymarketer' ), $response->get_error_message() );
				echo '</div>';
		} else {
			$data = $response['body'];
		}

		if ( $data ) {
			$doc = new DOMDocument();
			if($doc) {
				$doc->loadXML( $data );
			}
			$sourceNode = $doc->getElementsByTagName( 'authoritymarketer-theme-info' );
		}

		if ( $sourceNode ) {

			foreach ( $sourceNode as $source ) {
				$plugin_description = $source->getElementsByTagName( 'authoritymarketer-info-description' );
				printf($short_description = $plugin_description->item( 0 )->nodeValue);
			}
		}

	}
}// End if().

/* color customizer css */
function authoritymarketer_color_css() {
	global $color_data;

	require get_template_directory() . '/front-style.php';
	/* Customizer css */

	if ( isset( $color_data ) && $color_data != '' ) {
		wp_add_inline_style( 'authoritymarketer-style', $color_data );
	}
}

add_action( 'wp_enqueue_scripts', 'authoritymarketer_color_css' );

function authoritymarketer_autoinstall_box() {global $wpdb;

	$post_counts = $wpdb->get_var( $wpdb->prepare( "select count(p.ID) from $wpdb->posts p join $wpdb->postmeta pm on pm.post_id=p.ID where (meta_key=%s || meta_key=%s || meta_key=%s) and (meta_value=%d || meta_value=%s)",'pt_dummy_content','tl_dummy_content','auto_install',1,'auto_install' ) );

	/* help links */
	$menu_msg1 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/customize.php' ) ) . "'>" . esc_html__( 'Add your logo', 'authoritymarketer' ) . ' </a></li>';
	$menu_msg1 .= "<li><a href='" . esc_url( home_url( '/wp-admin/customize.php' ) ) . "'>" . esc_html__( 'Change site colors', 'authoritymarketer' ) . ' </a></li>';
	$menu_msg1 .= "<li><a href='" . esc_url( home_url( '/wp-admin/nav-menus.php?action=edit' ) ) . "'>" . esc_html__( 'Manage menu navigation', 'authoritymarketer' ) . '</a></li>';
	$menu_msg1 .= "<li><a href='" . esc_url( home_url( '/wp-admin/widgets.php' ) ) . "'>" . esc_html__( 'Manage sidebar widgets ', 'authoritymarketer' ) . ' </a></li></ul>';

	$menu_msg2 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/post-new.php' ) ) . "'>" . esc_html__( 'Add a Music', 'authoritymarketer' ) . '</a></li>';
	$menu_msg2 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/post-new.php' ) ) . "'>" . esc_html__( 'Add a Event', 'authoritymarketer' ) . '</a></li>';
	$menu_msg2 = "<ul><li><a href='" . esc_url( home_url( '/wp-admin/post-new.php' ) ) . "'>" . esc_html__( 'Add a Blog', 'authoritymarketer' ) . '</a></li>';
	$menu_msg2 .= "<li><a href='" . esc_url( home_url( '/wp-admin/post-new.php?post_type=page' ) ) . "'>" . esc_html__( 'Setup pages', 'authoritymarketer' ) . '</a></li></ul>';

	$my_theme = wp_get_theme();
	$theme_name = $my_theme->get( 'Name' );
	$version = $my_theme->get( 'Version' );

	$dummydata_title = '';
	$dummy_data_msg = '';
	$dummy_theme_message = '';
	$dummydata_title .= '<h3 class="twp-act-msg">' . sprintf( wp_kses( 'Thank you. %s (<small>v</small> %s) is now activated.', 'authoritymarketer',array( 'small' ) ), @wp_get_theme(), strtolower( $version ) ) . ' <a href="' . esc_url( home_url( '/' ) ) . '">Visit Your Site</a></h3>';

	/* system info goes in this filter */
	$dummydata_title = apply_filters( 'vintagejournal_after_install_delete_button', $dummydata_title );

	/* guilde and support link */

	$dummy_data_msg .= apply_filters( 'vintagejournal_after_install_delete_button', $dummy_data_msg );

	if ( $post_counts > 0 ) {

		$theme_name = get_option( 'stylesheet' );

		$dummy_data_msg = '';

		$dummy_data_msg = $dummydata_title;

		$dummy_data_text_msg = '

			<h4><span id="success_msg_install">' . esc_html__( 'All done. Your site is ready with sample data now.', 'authoritymarketer' ) . ' <a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'Visit your site', 'authoritymarketer' ) . '</a>.</span>
			<p>' . esc_html__( 'To make further adjustments to your site simply visit the', 'authoritymarketer' ) . ' <a href="' . esc_url( home_url( '/' ) ) . '">' . esc_html__( 'homepage', 'authoritymarketer' ) . '</a></p></h4><hr>
			<div id="install-notification" ><h4 id="install_message">' . esc_html__( 'Wish to delete sample data?', 'authoritymarketer' ) . ' </h4><p>' . esc_html__( 'Please note that deleting sample data will also remove any content you may have added or edited on any sample content. Deleting the sample data will also remove all sample widgets which were inserted.', 'authoritymarketer' ) . '</p><span><h4>' . esc_html__( 'I understand.', 'authoritymarketer' ) . ' <a class="button button-primary delete-data-button" href="' . esc_url( home_url( '/' ) ) . 'wp-admin/themes.php?page=editor-getting-started&dummy=del">' . esc_html__( 'Delete sample data', 'authoritymarketer' ) . '</a></h4></span>';

		$dummy_data_text_msg .= '<span id="install-notification-nonce" class="hidden">' . esc_attr( wp_create_nonce( 'install-notification-nonce' ) ) . '</span></div>';

		$dummy_data_msg .= $dummy_theme_message;

	} else {

		$theme_name = get_option( 'stylesheet' );

		$dummy_data_msg = '';

		$dummy_data_msg = $dummydata_title;

		$dummy_data_text_msg = '<div id="install-notification" class="tmpl-auto-install-yb"><h4>' . esc_html__( 'Before you begin, make sure all the required plugins are installed and activated.', 'authoritymarketer' ) . ' </h4> <span><a style="font-size:20px;" href="' . esc_url( home_url( '/' ) ) . 'wp-admin/themes.php?page=pt-one-click-demo-import">' . esc_html__( 'Install sample data', 'authoritymarketer' ) . '</a></span> <p>' . esc_html__( 'So that you don&prime;t start on a blank site, the sample data will help you get started with the theme. The content includes some default settings, widgets in their locations, pages, posts and a few dummy posts.', 'authoritymarketer' ) . '</p>';

		$dummy_data_text_msg .= '<span id="install-notification-nonce" class="hidden">' . esc_attr( wp_create_nonce( 'install-notification-nonce' ) ) . '</span></div>';

		$dummy_data_msg .= $dummy_theme_message;
	}

	$theme_name = get_option( 'stylesheet' );

	$dummy_data_msg = '';
	$dummy_data_msg_l = '';
	$dummy_data_msg = $dummydata_title;

	$licencekey_frm = '<h2>' . esc_html__( 'Your site not looking like our online demo?', 'authoritymarketer' ) . '</h2><div class="sample-data-wrap">' . $dummy_data_text_msg . do_action( 'vintagejournal_error_message' ) . '</div>';

	$dummy_data_msg .= '

		<form action="#" name="" method="post">

		<div class="form-table">

			<div class="theme-step">

				<div class="licence-key">

					' . $licencekey_frm . '

					</div>	';

	$dummy_data_msg .= '</div>';

	$dummy_data_msg .= "<div class='sample-data'>" . $dummy_theme_message . '</div></div>';
	$dummy_data_msg .= '</form>';

	 echo '<div id="ajax-notification" class="welcome-panel tmpl-welcome-panel"><div class="welcome-panel-content">' . $dummy_data_msg . '</div></div>';

	/* Delete the dummy data */
	if ( isset( $_REQUEST['dummy'] ) && $_REQUEST['dummy'] == 'del' ) {
		vintagejournal_delete_dummy_data();
		update_option( 'listing_xml', 0 );
		$url = admin_url() . 'themes.php';
		wp_redirect( admin_url() . 'themes.php?page=editor-getting-started' );
	}

	if ( isset( $_REQUEST['dummy_insert'] ) && $_REQUEST['dummy_insert'] == 1 ) {

		$theme_name = str_replace( ' ', '', strtolower( wp_get_theme() ) );

		wp_redirect( esc_url( admin_url( '/' ) . 'themes.php?page=editor-getting-started&x=y' ) );
	}
}

/*	include xml file for auto install. */
/*add_action( 'admin_init','autoritymarketer_auto_install_xml_file' );
function autoritymarketer_auto_install_xml_file() {
	if ( isset( $_REQUEST['dummy_insert'] ) && $_REQUEST['dummy_insert'] ) {

		
		if ( file_exists( get_template_directory() . '/inc/admin/auto-install/auto_install_xml.php' ) ) {

			require_once( get_template_directory() . '/inc/admin/auto-install/auto_install_xml.php' );

		}
	}
}


// Demo data importer
require_once get_template_directory() . '/inc/demo-importer.php';*/
// Install Plugins

require get_template_directory() . '/inc/lib/init-tgmpa.php';

// Merlin WP
function templatic_merlin()
{
    require get_template_directory() . '/inc/lib/merlin/vendor/autoload.php';
    require get_template_directory() . '/inc/lib/merlin/merlin.php';
    require get_template_directory() . '/inc/lib/merlin-config.php';
}
add_action('after_setup_theme', 'templatic_merlin');
?>
