<?php
/**
 * Theme updater admin page and functions.
 *
 * @package Editor
 */

/**
 * Redirect to Getting Started page on theme activation
 */
function editor_redirect_on_activation() {
	global $pagenow;

	if ( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) {

		wp_redirect( admin_url( 'themes.php?page=editor-getting-started' ) );

	}
}
add_action( 'admin_init', 'editor_redirect_on_activation' );

/**
 * Load Getting Started styles in the admin
 *
 * since 1.0.0
 */
function editor_start_load_admin_scripts() {

	// Load styles only on our page
	global $pagenow;
	if ( 'themes.php' != $pagenow ) {
		return;
	}

	/**
	 * Getting Started scripts and styles
	 *
	 * @since 1.0
	 */

	// Getting Started javascript
	wp_enqueue_script( 'editor-getting-started', get_template_directory_uri() . '/inc/admin/get-started.js', array( 'jquery' ), '1.0.0', true );

	// Getting Started styles
	wp_register_style( 'editor-getting-started', get_template_directory_uri() . '/inc/admin/get-started.css', false, '1.0.0' );
	wp_enqueue_style( 'editor-getting-started' );

	// Thickbox
	add_thickbox();
}
add_action( 'admin_enqueue_scripts', 'editor_start_load_admin_scripts' );

/**
 * Adds a menu item for the Getting Started page
 *
 * since 1.0.0
 */
function license_menu() {
	add_theme_page(
		esc_html__( 'Getting Started', 'authoritymarketer' ),
		esc_html__( 'Getting Started', 'authoritymarketer' ),
		'manage_options',
		'editor-getting-started',
		'editor_getting_started'
	);
}
add_action( 'admin_menu', 'license_menu' );

/**
 * Outputs the markup used on the theme license page.
 *
 * since 1.0.0
 */
function editor_getting_started() {

	/**
	 * Retrieve help file and theme update changelog
	 *
	 * since 1.0.0
	 */

	// Theme info
	$theme = wp_get_theme( 'authoritymarketer' );

?>

		<div class="wrap getting-started">
			<h2 class="notices"></h2>
			<div class="intro-wrap">
				<div class="intro">
					<h3><?php esc_html_e( 'Getting started', 'authoritymarketer' ); ?></h3>
					<h4><?php esc_html_e( 'You will find everything you need to get started here.', 'authoritymarketer' ); ?></h4>
				</div>
			</div>

			<div class="panels">
				<ul class="inline-list">
					<li class="current"><a id="help-tab" href="#"><?php esc_html_e( 'Help File', 'authoritymarketer' ); ?></a></li>
					<li><a id="themes-tab" href="#"><?php esc_html_e( 'Download More Free Themes!', 'authoritymarketer' ); ?></a></li>
					<li><a id="plugins-tab" href="#"><?php esc_html_e( 'Download More Free Plugins!', 'authoritymarketer' ); ?></a></li>
				</ul>

				<div id="panel" class="panel">

					<div id="help-panel" class="panel-left visible">
						<?php
							/* auto install for this theme. */
							require get_template_directory() . '/inc/admin/auto-install/auto_install.php';

							authoritymarketer_autoinstall_box();
						?>
						<!-- Grab feed of help file -->
						<?php  do_action( 'authoritymarketer_help' ) ?>

					</div>


					<!-- More themes -->
					<div id="themes-panel" class="panel-left">
						<div class="theme-intro">
							<div class="theme-intro-left">
								<p><?php _e( 'Build a professional looking website with one of the best free wordpress themes by <strong> Templatic. </strong>!', 'authoritymarketer' ); ?></p>
							</div>
							<div class="theme-intro-right">
								<a class="button-primary club-button" href="<?php echo esc_url( 'https://templatic.com/wordpress-themes-store/' ); ?>"><?php esc_html_e( 'Check out Premium Themes by Templatic', 'authoritymarketer' ); ?> &rarr;</a>
							</div>
						</div>

						<?php do_action( 'authoritymarketer_free_themes' );?>

					</div><!-- .panel-left updates -->

					<!-- More Plugins -->
					<div id="themes-panel" class="panel-left">
						<div class="theme-intro">
							<div class="theme-intro-left">
								<p><?php printf( 'Free wordpress Plugins by <strong> Templatic. </strong>!', 'authoritymarketer' ); ?></p>
							</div>
							<div class="theme-intro-right">
								<a class="button-primary club-button" href="<?php echo esc_url( 'https://templatic.com/wordpress-plugins/' ); ?>"><?php esc_html_e( 'Check out Premium Plugins by Templatic', 'authoritymarketer' ); ?> &rarr;</a>
							</div>
						</div>

						<?php do_action( 'authoritymarketer_free_plugins' );?>

					</div><!-- .panel-left updates -->

					<div class="panel-right">
						<div class="panel-aside panel-club">
							<a target="_blank" href="<?php echo esc_url( 'https://templatic.com/premium-themes-club/' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/club.jpg'; ?>" alt="<?php esc_html_e( 'Join the Theme Club!', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<h4><?php esc_html_e( 'Get an entire collection of beautiful, responsive themes for one low price.', 'authoritymarketer' ); ?></h4>

								<p><?php esc_html_e( 'The Theme Club grants you access to our collection of pixel-perfect WordPress themes, new theme releases and speedy, expert support for one year &mdash; a massive value!', 'authoritymarketer' ); ?></p>

								<a target="_blank" class="button-primary club-button" href="<?php echo esc_url( 'https://templatic.com/premium-themes-club/' ); ?>"><?php esc_html_e( 'Learn about the Theme Club', 'authoritymarketer' ); ?> </a>
							</div>

						</div>
						<h3><?php esc_html_e( 'Other Products', 'authoritymarketer' ); ?></h3>
						<div class="panel-aside panel-club">

							<a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/directory-theme' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/directory_theme.jpg'; ?>" alt="<?php esc_html_e( 'Directory Theme', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'Directory theme is ideal for creating an online listings directory. Includes custom post types, membership packages, geolocation, Google map search, unlimited searchable custom fields, advanced search and more. This WordPress directory theme comes with hundreds of built-in functions.', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/directory-theme' ); ?>"><?php esc_html_e( 'Read More..', 'authoritymarketer' ); ?> </a></p>
							</div>
							<a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/eventum-event-directory-theme' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/eventum_theme.jpg'; ?>" alt="<?php esc_html_e( 'Eventum Theme', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'Create a powerful events portal for event organizers with Eventum. This events WordPress theme helps you create, manage and monetize your events directory site for literally any purpose. Includes all the powerful options from our Directory theme plus it comes with its own event functions.', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/eventum-event-directory-theme' ); ?>"><?php esc_html_e( 'Read More..', 'authoritymarketer' ); ?> </a></p>
							</div>
							<a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/classifieds-directory-theme-for-wordpress' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/classified_theme.jpg'; ?>" alt="<?php esc_html_e( 'Classified Theme', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'This is a very powerful Classifieds theme for WordPress. Includes many customizable search options, monetization and classified ads submission packages. As with all of our directory themes, you can add your own categories, packages, menus and customize fields from the dashboard.', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/classifieds-directory-theme-for-wordpress' ); ?>"><?php esc_html_e( 'Read More..', 'authoritymarketer' ); ?> </a></p>
							</div>
							<a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/homequest-realestate-theme' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/homequest_theme.jpg'; ?>" alt="<?php esc_html_e( 'Homequest Theme', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'HomeQuest is one of our best and newest real estate WordPress themes. This is perfect if you want to create a property website or real estate classified ads directory. Use this theme as an estate agent to only advertise the properties on your portfolio or open property listing submission. ', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://templatic.com/app-themes/homequest-realestate-theme' ); ?>"><?php esc_html_e( 'Read More..', 'authoritymarketer' ); ?> </a></p>
							</div>

						</div>
						<h3><?php esc_html_e( 'Free Plugins', 'authoritymarketer' ); ?></h3>
						<div class="panel-aside panel-club">

							<a target="_blank" href="<?php echo esc_url( 'https://wordpress.org/plugins/templatic-categoryicons/' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/easy-category-icons.jpg'; ?>" alt="<?php esc_html_e( 'Directory Theme', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'A simple way to add images or font awesome icons to your categories and other custom taxonomies.', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://downloads.wordpress.org/plugin/templatic-categoryicons.zip' ); ?>"><?php esc_html_e( 'Download Now!', 'authoritymarketer' ); ?> </a></p>
							</div>
							<a target="_blank" href="<?php echo esc_url( 'https://wordpress.org/plugins/templatic-singletemplate/' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/custom-post-template.jpg'; ?>" alt="<?php esc_html_e( 'Templatic single template', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'This plugin allows theme authors to include single post templates, It is much like how admin use page template files while creating a page.', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://downloads.wordpress.org/plugin/templatic-singletemplate.zip' ); ?>"><?php esc_html_e( 'Download Now!.', 'authoritymarketer' ); ?> </a></p>
							</div>
							<a target="_blank" href="<?php echo esc_url( 'https://wordpress.org/plugins/templatic-google-amp/' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/templatic-google-AMP.jpg'; ?>" alt="<?php esc_html_e( 'Templatic google amp', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'This plugin adds support for the Accelerated Mobile Pages (AMP) Project, which aims to provide mobile optimized content that can load instantly.', 'authoritymarketer' ); ?> <a target="_blank" href="<?php echo esc_url( 'https://downloads.wordpress.org/plugin/templatic-google-amp.zip' ); ?>"><?php esc_html_e( 'Download Now!', 'authoritymarketer' ); ?> </a></p>
							</div>
							<a target="_blank" href="<?php echo esc_url( 'https://wordpress.org/plugins/templatic-badge/' ); ?>"><img src="<?php echo get_template_directory_uri() . '/inc/admin/post-badges.jpg'; ?>" alt="<?php esc_html_e( 'Post badges', 'authoritymarketer' ); ?>" /></a>

							<div class="panel-club-inside">
								<p><?php esc_html_e( 'This add-on allows you to display a badge on your listings , where you can set label and color for the badge. ', 'authoritymarketer' ); ?> <a target="_blank"href="<?php echo esc_url( 'https://downloads.wordpress.org/plugin/templatic-badge.zip' ); ?>"><?php esc_html_e( 'Download Now!', 'authoritymarketer' ); ?> </a></p>
							</div>

						</div>

					</div><!-- .panel-right -->

				</div><!-- .panel -->

			</div><!-- .panels -->

		</div><!-- .getting-started -->

	<?php
}
