<?php
/**
 * Custom template tags for this theme.
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package authoritymarketer
 */

if ( ! function_exists( 'authoritymarketer_posted_on' ) ) :
	/**
 * Prints HTML with meta information for the current post-date/time and author.
 */
	function authoritymarketer_posted_on() {
		global $post;
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';
		if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
			$time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
		}

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( 'c' ) ),
			esc_html( get_the_date() ),
			esc_attr( get_the_modified_date( 'c' ) ),
			esc_html( get_the_modified_date() )
		);

			$posted_on = sprintf(
				esc_html_x( '%s', 'post date', 'authoritymarketer' ),
				$time_string
			);

			$byline = sprintf(
				esc_html_x( '%s', 'post author', 'authoritymarketer' ),
				'by <span class="post-author vcard" itemprop="author" itemscope itemtype="https://schema.org/Person"><span itemprop="name"><a itemprop="name" class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span></span>'
			);
			echo ' <p class="byline"> ' . wp_kses( $byline, wp_kses_allowed_html( 'post' ) ) . '</p>';
			authoritymarketer_post_categories_tags();
			echo '<span class="hr">/</span><span class="posted-on" datetime="' . get_the_time( 'c' ) . '" itemprop="datePublished" content="' . get_the_time( 'c' ) . '"><i class="fa fa-calendar-o"></i>' . wp_kses( $posted_on, wp_kses_allowed_html( 'post' ) ) . '</span>'; // WPCS: XSS OK.

	}
endif;

function authoritymarketer_post_categories_tags() {
	global $post;

	$taxonomies = get_object_taxonomies( (object) array(
		'post_type' => $post->post_type,
		'public' => true,
		'_builtin' => true,
	) );
	$taxonomy_category = '';
	$terms = get_the_terms( $post->ID, $taxonomies[0] );
	$sep = ', ';
	$i = 0;
	if ( ! empty( $terms ) ) {
		//if(!empty($terms)){
		foreach ( $terms as $term ) {
			if ( $i == ( count( $terms ) - 1) ) {
				$sep = '';
			} elseif ( $i == ( count( $terms ) - 2) ) {
				$sep = __( ', ','authoritymarketer' );
			}
			$term_link = get_term_link( $term, $taxonomies[0] );
			if ( is_wp_error( $term_link ) ) {
				continue;
			}
			$taxonomy_category .= '<a href="' . esc_url( $term_link ) . '">' . esc_attr( $term->name ) . '</a>' . $sep;
			$i++;
		}

		 echo '<span class="cate"><i class="fa fa-folder-open-o"></i>' . esc_html__( ' ','authoritymarketer' ) . ' ' . wp_kses( $taxonomy_category, wp_kses_allowed_html( 'post' ) ) . '</span>';
		echo '</span>';
	}

}

if ( ! function_exists( 'authoritymarketer_content_nav' ) ) :
	/**
 * Display navigation to next/previous pages when applicable.
 */
	function authoritymarketer_content_nav( $nav_id ) {
		global $wp_query, $post;

		// Don't print empty markup on single pages if there's nowhere to navigate.
		if ( is_single() ) {
			$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
			$next = get_adjacent_post( false, '', false );

			if ( ! $next && ! $previous ) {
				return;
			}
		}

		// Don't print empty markup in archives if there's only one page.
		if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) ) {
			return;
		}

		$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

		?>
		<nav id="<?php echo esc_attr( $nav_id ); ?>" class="clearfix <?php echo esc_attr( $nav_class ); ?>" role="navigation">
		<?php if ( is_single() ) : ?>

		<?php previous_post_link( '<div class="nav-previous">%link</div>', '<span class="meta-nav">' . _x( '<i class="fa fa-angle-left"></i> Previous Article', 'Previous Article', 'authoritymarketer' ) . '</span> %title' ); ?>
		<?php next_post_link( '<div class="nav-next">%link</div>', '<span class="meta-nav">' . _x( 'Next Article <i class="fa fa-angle-right"></i>', 'Next Article', 'authoritymarketer' ) . '</span> %title' ); ?>

	<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : ?>

		<?php if ( get_next_posts_link() ) : ?>
		<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav"><i class="fa fa-chevron-left"></i></span> Previous Articles', 'authoritymarketer' ) ); ?></div>
		<?php endif; ?>

		<?php if ( get_previous_posts_link() ) : ?>
		<<div class="nav-next"><?php previous_posts_link( __( 'Next Articles <span class="meta-nav"><i class="fa fa-chevron-right"></i></span>', 'authoritymarketer' ) ); ?></div>
		<?php endif; ?>

	<?php endif; ?>

		</nav><!-- #<?php echo esc_html( $nav_id ); ?> -->
		<?php
	}
endif;

/**
 * Returns true if a blog has more than 1 category.
 *
 * @return bool
 */
function authoritymarketer_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'authoritymarketer_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			// We only need to know if there is more than one category.
			'number'     => 2,
		) );

		// Count the number of categories that are attached to the posts.
		$all_the_cool_cats = count( $all_the_cool_cats );

		set_transient( 'authoritymarketer_categories', $all_the_cool_cats );
	}

	if ( $all_the_cool_cats > 1 ) {
		// This blog has more than 1 category so authoritymarketer_categorized_blog should return true.
		return true;
	} else {
		// This blog has only 1 category so authoritymarketer_categorized_blog should return false.
		return false;
	}
}
